<template>
  <div
    v-if="showIncome"
    id="accounting">
    <h1>Sales</h1>
    <table
      id="salesIncomeTable"
      :class="{'closed':!expandSales}"
      class="sales">
      <thead  v-if="expandSales === true">
        <tr>
          <th>Time</th>
          <th>From</th>
          <th>Account Number</th>
          <th>Amount</th>
          <td>&nbsp;</td>
        </tr>
      </thead>
      <tbody v-if="salesObject.sales && expandSales == true" >
        <tr
          v-for="(sale, index) in salesObject.sales"
          :key="index">
          <td>{{ moment.utc(sale.time).local().format('h:mm A') }}</td>
          <td>{{ sale.account_name }}</td>
          <td>{{ sale.from }}</td>
          <td>${{ sale.amount.toFixed(2) }}</td>
          <td><a
            class="voidTransaction button"
            @click="deleteSale(sale)" >VOID</a></td>
        </tr>
      </tbody>
      <tfoot>
        <tr class="lastrow">
          <td>Sales Total</td>
          <td
            v-if="salesObject.totalSales"
            style="font-size: 2.2em; !important"
            class="salesIncomeTotal">${{ salesObject.totalSales.toFixed(2) }}
          </td>
          <td
            v-else
            style="font-size: 2.2em; !important">$0.00</td>
          <td>&nbsp;</td>
          <td><a
            class="expand"
            @click="expandSales = !expandSales"><span class="arrow-down"/><span class="arrow-right"/></a></td>
          <td>&nbsp;</td>
        </tr>
      </tfoot>
    </table>
    <h1>Investment Management Fees</h1>
    <table class="fees">
      <tfoot>
        <tr class="lastrow">
          <td>Investment Management Fees Total</td>
          <td>&nbsp;</td>
          <td>&nbsp;</td>
          <td>$<span class="managementFees">{{ incomeObject.total.toFixed(2) }}</span></td>
        </tr>
      </tfoot>
    </table>
    <h1>Total</h1>
    <table class="total">
      <tfoot>
        <tr class="lastrow">
          <td>Sales Income + Investment Management Fees</td>
          <td>&nbsp;</td>
          <td>&nbsp;</td>
          <td>
            <span
              v-if="!Object.keys(salesObject).length && !Object.keys(incomeObject).length"
              class="totalIncome">$0.00
            </span>
            <span
              v-else-if="!Object.keys(salesObject).length && Object.keys(incomeObject).length"
              class="totalIncome">${{ (incomeObject.received).toFixed(2) }}
            </span>
            <span
              v-else-if="Object.keys(salesObject).length && !Object.keys(incomeObject).length"
              class="totalIncome">${{ (salesObject.totalSales).toFixed(2) }}
            </span>
            <span
              v-else
              class="totalIncome">${{ (incomeObject.received + salesObject.totalSales).toFixed(2) }}
            </span>
          </td>
        </tr>
      </tfoot>
    </table>
  </div>
</template>

<script>
export default {
  props: {
    shop: Object,
    sales: Array,
    showIncome: Boolean,
  },
  data() {
    return {
      showSales: true,
      // TODO: should be total of transactions of type investment
      incomeObject: Object,
      salesObject: Object,
      expandSales: false,
      intervalID: ""
    };
  },
  created: function() {
    // this.getPaymentData();
    this.getSalesData();
    this.poller();
  },
  destroyed: function() {
    clearInterval(this.intervalID);
  },
  methods : {
    // income from transaction type investment
    // getPaymentData(){
    //   app.api.Get( "/shop_payment/getPaymentsByShopType/" + this.shop.canonical_name).then( response => {
    //     this.incomeObject = response;
    //   }
    // )},
  togglePayment(income){
    app.api.Put( "/shop_payment/toggleByShopPayment/" + income.id).then( response => {
      this.getPaymentData();
    });
    },
  getSalesData(){
      app.api.Get( "/transaction/getSalesByShop/" + this.shop.canonical_name).then( response => {
        this.salesObject = response;
      });
    },
    deleteSale(sale){
        var result = confirm( "Void payment?" );
        if(result){
          app.api.Delete( "/transaction/" + sale.id).then( response => {
            this.getSalesData();
        });
      }
    },
    poller() {
      this.intervalID = setInterval(() => {
        this.getSalesData();
      }, 10000);
    }
  }
};
</script>

